/*!
  * Licensed Materials - Property of IBM
  * 5725N95, 5725P55, 5725N96
  * (C) Copyright IBM Corp. 1999, 2014.
  * US Government Users Restricted Rights- Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

 /* $Id: PresentationNavigation.js,v 1.1.2.1 2015/06/22 09:21:34 rakollep Exp $ */
 
PresentationNavigation = function()
{
    this.curID				= "0";
	this.courseID 			= "0";
	this.loID 				= "0";
	this.topicID			= "0";
	this.groupID 			= "0";
	this.loStatus 			= "9";
	this.docMode 			= "WEB";
	this.studentRole 		= "s";
	this.studentID			= "admin";
	this.themeID			= "primaryangles";
	this.exportInProgress 	= false;
	this.instructorMode		= true;

	this.skipTopicTitle		= true;
	this.skipGroupTitle		= true;

	this.COOKIE_NAME		= "preferences";

	this.presTOP			= 0;
	this.presLEFT			= 0;
	this.presWIDTH			= 800;
	this.presHEIGHT			= 600;

	this.loTOP				= 0;
	this.loLEFT				= 0;
	this.loWIDTH			= 800;
	this.loHEIGHT			= 600;

	this.x					= 0;
	this.y					= 0;

	this.WINDOW_TOP_PADDING	= 24;	// pads the screenTop with enough height for the title
	this.WINDOW_LEFT_PADDING = 5;	// pads the screenTop with enough height for the left border
}

PresentationNavigation.prototype.init = function()
{
	this.loadCookieValues();

	this.updateForm();
	
	this.index = OSDeliveryEngine.find(OSDeliveryEngine.getRoot(), function(o) { return jQuery.inArray(o.type, [3,2,11,1]) != -1; });
	this.position = [0,0];

   	this.openPresentation();
}

PresentationNavigation.prototype.finalize = function()
{
	this.closeLO();
	this.closePresentation();
    this.setCookieValues();
}

PresentationNavigation.prototype.closeLO = function()
{
    if ((this.LO_WINDOW) && (!this.LO_WINDOW.closed))
    {
    	this.LO_WINDOW.close();
	}
}

PresentationNavigation.prototype.closePresentation = function()
{
    if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
    {
		this.PRES_WINDOW.close();
    }
}

PresentationNavigation.prototype.getWindowPositions = function()
{
    if ((this.LO_WINDOW) && (!this.LO_WINDOW.closed))
    {
    	this.loLEFT = (document.layers) ? this.LO_WINDOW.screenX : (this.LO_WINDOW.screenLeft - this.WINDOW_LEFT_PADDING);
    	this.loTOP = (document.layers) ? this.LO_WINDOW.screenY : (this.LO_WINDOW.screenTop - this.WINDOW_TOP_PADDING);
    }

    if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
    {
    	this.presLEFT = (document.layers) ? this.PRES_WINDOW.screenX : (this.PRES_WINDOW.screenLeft - this.WINDOW_LEFT_PADDING);
    	this.presTOP = (document.layers) ? this.PRES_WINDOW.screenY : (this.PRES_WINDOW.screenTop - this.WINDOW_TOP_PADDING);
    }
}

PresentationNavigation.prototype.openPresentation = function()
{
	var presURL = 	"PresSlide?"+
						"curID="+this.curID+
                        "&courseID="+this.courseID+
                        "&loID="+this.loID+
						"&loStatus="+this.loStatus+
						"&slideTitle="+encodeURI(this.loDESC)+
						"&contentTypeID=0"+
						"&slideNum=0"+
						"&objID="+this.loID+
						"&objLevel=3"+
						"&studentID="+this.studentID+
						"&studentRole="+this.studentRole+
						"&themeID="+this.themeID+
						// issue 55431 - these parms were not be passed into the serlvet
						"&skipTopics="+this.skipTopicTitle+
                        "&skipGroups="+this.skipGroupTitle+
						"&instructorMode="+this.instructorMode+
						"&visibleToolbar=0";

	this.PRES_WINDOW = window.open(presURL, "PresentationWindow", "height="+this.presHEIGHT+",width="+this.presWIDTH+",top="+this.presTOP+",left="+this.presLEFT+",toolbar=no,scrollbars=yes,menubar=no,resizable=no,status=no");
}

PresentationNavigation.prototype.updatePresentationSize = function(size)
{
        splitStr = size.split("*");
        this.presWIDTH = splitStr[0];
        this.presHEIGHT = splitStr[1];

	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		if (document.layers)
		{
			this.closePresentation();
			this.openPresentation();
		}
		else
		{
			this.PRES_WINDOW.resizeTo(this.presWIDTH,this.presHEIGHT);
			//this.openPresentation();
		}
	}
	if ((this.LO_WINDOW) && (!this.LO_WINDOW.closed))
	{
		if (document.layers)
		{
			this.closeLO();
			this.openLO();
		}
		else
		{
			this.LO_WINDOW.resizeTo(this.presWIDTH,this.presHEIGHT);
		}
	}
}

PresentationNavigation.prototype.updateForm = function()
{
	var form = document.forms[0];
	var resolution = "800*600";

	switch (parseInt(this.presWIDTH))
	{
		case (1600):
			resolution = "1600*1200";
			break;
		case (1280):
			resolution = "1280*1024";
			break;
		case (1024):
			resolution = "1024*768";
			break;
		case (800):
			resolution = "800*600";
			break;
	}

	for (var i=0; i<form.presSize.length; i++)
	{
		if (form.presSize[i].value == resolution)
		{
			form.presSize[i].selected = true;
		}
	}

	form.skipGroups.checked = this.skipGroupTitle;
	form.skipTopics.checked = this.skipTopicTitle;
}

PresentationNavigation.prototype.openLO = function()
{
	var pos = this.position[0];
	var current = this.index[pos];
	
	if ((this.LO_WINDOW) && (!this.LO_WINDOW.closed)) 
	{
		this.LO_WINDOW.ViewerController.navigateTo(current);
	} 
	else 
	{
		var loURL = "RloPage?"+ "curID="+this.curID+
		"&courseID="+this.courseID+
		"&loID="+this.loID+
		"&themeID="+this.themeID+
		"&studentID="+this.studentID+
		"&studentRole="+this.studentRole+
		"&exportInProgress="+this.exportInProgress;
		
		var groupID = "0";
		var topicID = "0";
		
		var o = current;
		do
		{
			if (o.type == 2)
			{
				loURL += "&topicID="+o.id;
			}
			else if (o.type == 11)
			{
				loURL += "&groupID="+o.id;
			}
		}
		while ((o = o.parent) != null);

		this.LO_WINDOW = window.open(loURL,"LearningObjectWindow","scrollbars=auto,width="+this.loWIDTH+",height="+this.loHEIGHT+",top="+this.loTOP+",left="+this.loLEFT+",resizable=no,status=no");
		this.LO_WINDOW.moveTo(this.loLEFT,this.loTOP);
	}
}

PresentationNavigation.prototype.navigationListener = function(type, arg)
{	
	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		var obj = arg[0];
		var local = null;
		do 
		{
			local = OSDeliveryEngine.getObjectByUniqueId(obj.uniqueId);
		}
		while (local == null && ((obj = obj.parent) != null))
		
		if (local != null)
		{
			var pos = jQuery.inArray(local,this.index);
			if (pos > -1)
			{
				var next = null;
				while ((pos < this.index.length) && next == null)
				{
					if (this.index[pos].type == 1)
					{
						next = this.index[pos];
					}
					else if (this.index[pos].type == 3)
					{
						next = this.index[pos];
					}
					else if (this.index[pos].type == 2 && !this.skipTopicTitle)
					{
						next = this.index[pos];
					}
					else if (this.index[pos].type == 11 && !this.skipGroupTitle)
					{
						next = this.index[pos];
					}
					else
					{
						pos++;
					}
				}
				
				if (next != null)
				{
					this.PRES_WINDOW.SlideController.navigate(next.uniqueId, 0);
					this.position = [pos,0];
				}
			}
		}
  	}
}

PresentationNavigation.prototype.prev = function()
{
	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		this.prevSlide();
  	}
}

PresentationNavigation.prototype.prevSlide = function()
{
	var pos = this.position[0];
	var build = this.position[1];
	
	var current = this.index[pos];

	var current = this.index[pos];
	if ((current.buildCnt) > 1 && (build > 0))
	{
		build--;
		this.PRES_WINDOW.SlideController.navigate(current.uniqueId, build);
	}
	else
	{
		var prev = null
		while (pos > 0 && prev == null)
		{
			pos--;
			if (this.index[pos].type == 1)
			{
				prev = this.index[pos];
				build = (prev.buildCnt) ? (prev.buildCnt-1) : 0;
			}
			else if (this.index[pos].type == 2 && !this.skipTopicTitle)
			{
				prev = this.index[pos];
				build = 0;
			}
			else if (this.index[pos].type == 11 && !this.skipGroupTitle)
			{
				prev = this.index[pos];
				build = 0;
			}
			else if (this.index[pos].type == 3)
			{
				prev = this.index[pos];
				build = 0;				
			}
		}
		
		if (prev != null)
		{
			this.PRES_WINDOW.SlideController.navigate(prev.uniqueId, build);
			
			if (this.LO_WINDOW && !this.LO_WINDOW.closed)
			{
				this.LO_WINDOW.ViewerController.navigateTo(prev);
			}
		}
	}

	this.position = [pos,build];
}

PresentationNavigation.prototype.next = function()
{
	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		this.nextSlide();		
  	}
}

PresentationNavigation.prototype.nextSlide = function()
{
	var pos = this.position[0];
	var build = this.position[1];
	
	var current = this.index[pos];
	if ((current.buildCnt) > 1 && (build < current.buildCnt-1))
	{
		build++;
		this.PRES_WINDOW.SlideController.navigate(current.uniqueId, build);
	}
	else
	{
		var next = null;
		while (pos < (this.index.length-1) && next == null)
		{
			pos++;
			if (this.index[pos].type == 1)
			{
				next = this.index[pos];
			}
			else if (this.index[pos].type == 2 && !this.skipTopicTitle)
			{
				next = this.index[pos];
			}
			else if (this.index[pos].type == 11 && !this.skipGroupTitle)
			{
				next = this.index[pos];
			}
		}
		
		if (next != null)
		{	
			build = 0;
			this.PRES_WINDOW.SlideController.navigate(next.uniqueId, build);
			
			if (this.LO_WINDOW && !this.LO_WINDOW.closed)
			{
				this.LO_WINDOW.ViewerController.navigateTo(next);
			}
		}
	}

	this.position = [pos,build];
}

PresentationNavigation.prototype.setSkipTopicTitle = function(state)
{
	this.skipTopicTitle = state;

	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		this.PRES_WINDOW.skipTopicTitle = this.skipTopicTitle;
		this.PRES_WINDOW.skipGroupTitle = this.skipGroupTitle;

		this.PRES_WINDOW.frames["pres_body"].doSlideCount();
	}
}

PresentationNavigation.prototype.setSkipGroupTitle = function(state)
{
	this.skipGroupTitle = state;

	if ((this.PRES_WINDOW) && (!this.PRES_WINDOW.closed))
	{
		this.PRES_WINDOW.skipTopicTitle = this.skipTopicTitle;
		this.PRES_WINDOW.skipGroupTitle = this.skipGroupTitle;
		this.PRES_WINDOW.frames["pres_body"].doSlideCount();
	}
}

PresentationNavigation.prototype.setCookieValues = function()
{
	var expDate = new Date();
		expDate.setYear(expDate.getYear()+1);

	document.cookie = 	this.COOKIE_NAME+"="+
							"navLEFT:"+this.x+
							"&navTOP:"+this.y+
							"&presLEFT:"+this.presLEFT+
							"&presTOP:"+this.presTOP+
							"&presWIDTH:"+this.presWIDTH+
							"&presHEIGHT:"+this.presHEIGHT+
							"&loLEFT:"+this.loLEFT+
							"&skipGroupTitle:"+this.skipGroupTitle+
							"&skipTopicTitle:"+this.skipTopicTitle+
							"&loTOP:"+this.loTOP+
							";expires="+expDate.toGMTString();
}

PresentationNavigation.prototype.loadCookieValues = function()
{
	if (document.cookie != null)
	{
		var cookieArray = document.cookie.split(";");
		
		for (var i=0; i<cookieArray.length; i++)
		{
			var cookieParts = cookieArray[i].split("=");
			var cookieName = cookieParts[0];
			var cookieValue = cookieParts[1];

			if (cookieName.indexOf(this.COOKIE_NAME) > -1)
			{
				var cookieElements = cookieValue.split("&");
				for (var e=0; e<cookieElements.length; e++)
				{
					var nameValueArray = cookieElements[e].split(":");

					var name = nameValueArray[0];
					var value = nameValueArray[1];

					if (name == "presTOP")
					{
						if (value != "Nan")
						{
							this.presTOP = value;
						}
					}
					else if (name == "presLEFT")
					{
						if (value != "Nan")
						{
							this.presLEFT = value;
						}
					}
					else if (name == "presWIDTH")
					{
						if (value != "Nan")
						{
							this.presWIDTH = value;
						}
					}
					else if (name == "presHEIGHT")
					{
						if (value != "Nan")
						{
							this.presHEIGHT = value;
						}
					}
					else if (name == "loTOP")
					{
						if (value != "Nan")
						{
							this.loTOP = value;
						}
					}
					else if (name == "loLEFT")
					{
						if (value != "Nan")
						{
							this.loLEFT = value;
						}
					}
					else if (name == "skipGroupTitle")
					{
						if (value == "false")
						{
							this.skipGroupTitle = false;
						}
					}
					else if (name == "skipTopicTitle")
					{
						if (value == "false")
						{
							this.skipTopicTitle = false;
						}
					}
					else if (name == "navTOP")
					{
						if (value != "Nan")
						{
							this.y = value;
						}
					}
					else if (name == "navLEFT")
					{
						if (value != "Nan")
						{
							this.x = value;
						}
					}
				}
			}
		}
	}
}

function Get_Cookie(name)
{
	  var start = document.cookie.indexOf(name+"=");
	  var len = start+name.length+1;
	  if ((!start) && (name != document.cookie.substring(0,name.length))) return null;
	  if (start == -1) return null;
	  var end = document.cookie.indexOf(";",len);
	  if (end == -1) end = document.cookie.length;
	  return unescape(document.cookie.substring(len,end));
}
function Set_Cookie(name,value,expires,path,domain,secure)
{
   document.cookie = name + "=" +escape(value) +
	 	  ( (expires) ? ";expires=" + expires.toGMTString() : "") +
		  ( (path) ? ";path=" + path : "") +
		  ( (domain) ? ";domain=" + domain : "") +
		  ( (secure) ? ";secure" : "");
}
function getCookieValues(string)
{
	  getValue(string,"user",   document.profileForm.user,   "text");
	  getValue(string,"email",  document.profileForm.email,  "text");
	  getValue(string,"country",document.profileForm.country,"select");
	  getValue(string,"age",    document.profileForm.age,    "select");
	  getValue(string,"sex",    document.profileForm.sex,    "radio");
}
function getValue(string,elementName,object,elementType)
{
    var startPos = string.indexOf(elementName + "=")
	if (startPos > -1)
	{
		startPos = startPos + elementName.length + 1;
		var endPos = string.indexOf("&",startPos);
		if (endPos == -1) endPos = string.length;
		var elementValue = unescape(string.substring(startPos,endPos));
		if (elementType == "text")     object.value = elementValue;
		if (elementType == "password") object.value = elementValue;
		if (elementType == "select")   object.selectedIndex = elementValue;
		if (elementType == "checkbox") object.checked = onCheck(elementValue);
		if (elementType == "radio")    object[elementValue].checked = true;
	}
}
 PresentationNavigation.prototype.printPresSlide = function()
{

	 this.PRES_WINDOW.print();
}
